# -*- coding: utf-8 -*-
"""
    SKF Tests
    ~~~~~~~~~~~~

"""

import pytest

import os
import skf
import tempfile


@pytest.fixture
def client(request):
    db_fd, skf.app.config['DATABASE'] = tempfile.mkstemp()
    skf.app.config['TESTING'] = True
    client = skf.app.test_client()
    with skf.app.app_context():
        skf.init_db()

    def teardown():
        os.close(db_fd)
        os.unlink(skf.app.config['DATABASE'])
    request.addfinalizer(teardown)

    return client


def login(client, username, password):
    return client.post('/login', data=dict(
        username=username,
        password=password
    ), follow_redirects=True)


def logout(client):
    return client.get('/logout', follow_redirects=True)


def test_empty_db(client):
    """Start with a blank database."""
    rv = client.get('/')
    assert b'No entries here so far' in rv.data


def test_login_logout(client):
    """Make sure login and logout works"""
    rv = login(client, skf.app.config['USERNAME'],
               skf.app.config['PASSWORD'])
    assert b'You were logged in' in rv.data
    rv = logout(client)
    assert b'You were logged out' in rv.data
    rv = login(client, skf.app.config['USERNAME'] + 'x',
               skf.app.config['PASSWORD'])
    assert b'Invalid username' in rv.data
    rv = login(client, skf.app.config['USERNAME'],
               skf.app.config['PASSWORD'] + 'x')
    assert b'Invalid password' in rv.data


def test_messages(client):
    """Test that messages work"""
    login(client, skf.app.config['USERNAME'],
          skf.app.config['PASSWORD'])
    rv = client.post('/add', data=dict(
        title='<Hello>',
        text='<strong>HTML</strong> allowed here'
    ), follow_redirects=True)
    assert b'No entries here so far' not in rv.data
    assert b'&lt;Hello&gt;' in rv.data
    assert b'<strong>HTML</strong> allowed here' in rv.data




try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

setup(name='owasp-skf',
    version='0.2.5a3',
    description='The OWASP Security Knowledge Framework',
    url='https://github.com/blabla1337/skf-flask',
    author='Glenn ten Cate, Riccardo ten Cate',
    author_email='gtencate@schubergphilis.com, r.tencate77@gmail.com',
    license='AGPLV3',
    packages=['skf'],
    # trying to add files...
    include_package_data = True,
    dependency_links = ['https://github.com/mitsuhiko/flask/tarball/master'],
    long_description="""\
    The Security Knowledge Framework is an fully open-source Python-Flask web-application.
    It is an expert system application that uses OWASP Application Security Verification Standard 
    """,
    install_requires=open('requirements.txt').read().splitlines(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Framework :: Flask",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
    ])


